import { Injectable } from '@nestjs/common';
import { InjectModel } from '@nestjs/sequelize';
import { Op } from 'sequelize';
import { col, fn } from 'sequelize';
import { User } from '../user/user.model';
import { Rank } from './rank.model';

@Injectable()
export class RankService {
  constructor(@InjectModel(Rank) private rankModel: typeof Rank) {}

  async create(points, userId): Promise<Rank> {
    const rank = await this.findByUserLatest(userId);
    return this.rankModel.create({
      points: rank ? rank.points + points : points,
      userId,
    });
  }

  async findAll(): Promise<Rank[]> {
    return this.rankModel.findAll();
  }

  async findByUser(userId: string): Promise<Rank[]> {
    return this.rankModel.findAll({
      where: {
        userId,
      },
    });
  }

  async findByUserLatest(userId: string): Promise<Rank> {
    return this.rankModel.findOne({
      where: {
        userId,
      },
      order: ['createdAt', 'DESC'],
    });
  }

  async findRankList(): Promise<Rank[]> {
    return this.rankModel
      .findAll({
        attributes: ['id', [fn('MAX', col('createdAt')), 'mDate'], 'userId'],
        group: ['userId'],
      })
      .then((res) => {
        const maxIds = [];
        res.forEach((r) => {
          maxIds.push(r.id);
        });
        return this.rankModel.findAll({
          attributes: ['id', 'points'],
          where: {
            id: {
              [Op.in]: maxIds,
            },
          },
          include: [
            {
              model: User,
              attributes: ['name'],
            },
          ],
        });
      });
  }
}
